@@ -262,7 +262,7 @@ class LongHandlerEN(Operation):
                 self.bracket_left += 1
             if self.symbols['bracket_right'].match(state[i]):
                self.bracket_right += 1
-        self.pre_index = org_pointer
+        #self.pre_index = org_pointer
         self.pre_sentence_start = state.sentence_start
 
 
